@@ -137,7 +137,7 @@ impl Node {
     // If newly encountered pointer, wrap
     let node = _Node {
       node_ptr,
-      document: Rc::downgrade(&document),
+      document: Rc::downgrade(document),
       unlinked,
     };
     let wrapped_node = Node(Rc::new(RefCell::new(node)));
@@ -170,7 +170,7 @@ impl Node {
   }
   /// Create a mock node, used for a placeholder argument
   pub fn mock(doc: &Document) -> Self {
-    Node::new("mock", None, &doc).unwrap()
+    Node::new("mock", None, doc).unwrap()
   }
 
   /// Create a mock node, used for a placeholder argument
@@ -335,7 +335,10 @@ impl Node {
   }
 
   /// Add a previous sibling
-  pub fn add_prev_sibling(&mut self, new_sibling: &mut Node) -> Result<(), Box<dyn Error>> {
+  pub fn add_prev_sibling(
+    &mut self,
+    new_sibling: &mut Node,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     new_sibling.set_linked();
     unsafe {
       if xmlAddPrevSibling(self.node_ptr_mut()?, new_sibling.node_ptr_mut()?).is_null() {
@@ -347,7 +350,10 @@ impl Node {
   }
 
   /// Add a next sibling
-  pub fn add_next_sibling(&mut self, new_sibling: &mut Node) -> Result<(), Box<dyn Error>> {
+  pub fn add_next_sibling(
+    &mut self,
+    new_sibling: &mut Node,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     new_sibling.set_linked();
     unsafe {
       if xmlAddNextSibling(self.node_ptr_mut()?, new_sibling.node_ptr_mut()?).is_null() {
@@ -358,7 +364,7 @@ impl Node {
     }
   }
 
-  /// Returns true iff it is a text node
+  /// Returns true if it is a text node
   pub fn is_text_node(&self) -> bool {
     self.get_type() == Some(NodeType::TextNode)
   }
@@ -384,7 +390,7 @@ impl Node {
   }
 
   /// Sets the name of this `Node`
-  pub fn set_name(&mut self, name: &str) -> Result<(), Box<dyn Error>> {
+  pub fn set_name(&mut self, name: &str) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     unsafe { xmlNodeSetName(self.node_ptr_mut()?, c_name.as_bytes().as_ptr()) }
     Ok(())
@@ -407,7 +413,7 @@ impl Node {
   }
 
   /// Sets the text content of this `Node`
-  pub fn set_content(&mut self, content: &str) -> Result<(), Box<dyn Error>> {
+  pub fn set_content(&mut self, content: &str) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_content = CString::new(content).unwrap();
     unsafe { xmlNodeSetContent(self.node_ptr_mut()?, c_content.as_bytes().as_ptr()) }
     Ok(())
@@ -460,8 +466,40 @@ impl Node {
     }
   }
 
+  /// Check if a property has been defined, without allocating its value
+  pub fn has_property(&self, name: &str) -> bool {
+    let c_name = CString::new(name).unwrap();
+    let value_ptr = unsafe { xmlHasProp(self.node_ptr(), c_name.as_bytes().as_ptr()) };
+    !value_ptr.is_null()
+  }
+  /// Check if property `name` in namespace `ns` exists
+  pub fn has_property_ns(&self, name: &str, ns: &str) -> bool {
+    let c_name = CString::new(name).unwrap();
+    let c_ns = CString::new(ns).unwrap();
+    let value_ptr = unsafe {
+      xmlHasNsProp(
+        self.node_ptr(),
+        c_name.as_bytes().as_ptr(),
+        c_ns.as_bytes().as_ptr(),
+      )
+    };
+    !value_ptr.is_null()
+  }
+  /// Alias for has_property
+  pub fn has_attribute(&self, name: &str) -> bool {
+    self.has_property(name)
+  }
+  /// Alias for has_property_ns
+  pub fn has_attribute_ns(&self, name: &str, ns: &str) -> bool {
+    self.has_property_ns(name, ns)
+  }
+
   /// Sets the value of property `name` to `value`
-  pub fn set_property(&mut self, name: &str, value: &str) -> Result<(), Box<dyn Error>> {
+  pub fn set_property(
+    &mut self,
+    name: &str,
+    value: &str,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     let c_value = CString::new(value).unwrap();
     unsafe {
@@ -479,7 +517,7 @@ impl Node {
     name: &str,
     value: &str,
     ns: &Namespace,
-  ) -> Result<(), Box<dyn Error>> {
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     let c_value = CString::new(value).unwrap();
     unsafe {
@@ -494,7 +532,7 @@ impl Node {
   }
 
   /// Removes the property of given `name`
-  pub fn remove_property(&mut self, name: &str) -> Result<(), Box<dyn Error>> {
+  pub fn remove_property(&mut self, name: &str) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     unsafe {
       let attr_node = xmlHasProp(self.node_ptr_mut()?, c_name.as_bytes().as_ptr());
@@ -517,14 +555,18 @@ impl Node {
   }
 
   /// Removes the property of given `name` and namespace (`ns`)
-  pub fn remove_property_ns(&mut self, name: &str, ns: &str) -> Result<(), Box<dyn Error>> {
+  pub fn remove_property_ns(
+    &mut self,
+    name: &str,
+    ns: &str,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     let c_ns = CString::new(ns).unwrap();
     unsafe {
       let attr_node = xmlHasNsProp(
-          self.node_ptr_mut()?,
-          c_name.as_bytes().as_ptr(),
-          c_ns.as_bytes().as_ptr(),
+        self.node_ptr_mut()?,
+        c_name.as_bytes().as_ptr(),
+        c_ns.as_bytes().as_ptr(),
       );
       if !attr_node.is_null() {
         let remove_prop_status = xmlRemoveProp(attr_node);
@@ -559,7 +601,11 @@ impl Node {
   }
 
   /// Alias for set_property
-  pub fn set_attribute(&mut self, name: &str, value: &str) -> Result<(), Box<dyn Error>> {
+  pub fn set_attribute(
+    &mut self,
+    name: &str,
+    value: &str,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     self.set_property(name, value)
   }
   /// Alias for set_property_ns
@@ -568,17 +614,21 @@ impl Node {
     name: &str,
     value: &str,
     ns: &Namespace,
-  ) -> Result<(), Box<dyn Error>> {
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     self.set_property_ns(name, value, ns)
   }
 
   /// Alias for remove_property
-  pub fn remove_attribute(&mut self, name: &str) -> Result<(), Box<dyn Error>> {
+  pub fn remove_attribute(&mut self, name: &str) -> Result<(), Box<dyn Error + Send + Sync>> {
     self.remove_property(name)
   }
 
   /// Alias for remove_property_ns
-  pub fn remove_attribute_ns(&mut self, name: &str, ns: &str) -> Result<(), Box<dyn Error>> {
+  pub fn remove_attribute_ns(
+    &mut self,
+    name: &str,
+    ns: &str,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     self.remove_property_ns(name, ns)
   }
 
@@ -668,7 +718,10 @@ impl Node {
   }
 
   /// Sets a `Namespace` for the node
-  pub fn set_namespace(&mut self, namespace: &Namespace) -> Result<(), Box<dyn Error>> {
+  pub fn set_namespace(
+    &mut self,
+    namespace: &Namespace,
+  ) -> Result<(), Box<dyn Error + Send + Sync>> {
     unsafe {
       xmlSetNs(self.node_ptr_mut()?, namespace.ns_ptr());
     }
@@ -722,7 +775,7 @@ impl Node {
 
   // TODO: Clear a future Document namespaces vec
   /// Removes the namespaces of this `Node` and it's children!
-  pub fn recursively_remove_namespaces(&mut self) -> Result<(), Box<dyn Error>> {
+  pub fn recursively_remove_namespaces(&mut self) -> Result<(), Box<dyn Error + Send + Sync>> {
     xmlNodeRecursivelyRemoveNs(self.node_ptr_mut()?);
     Ok(())
   }
@@ -752,7 +805,11 @@ impl Node {
   }
 
   /// Creates a new `Node` as child to the self `Node`
-  pub fn new_child(&mut self, ns: Option<Namespace>, name: &str) -> Result<Node, Box<dyn Error>> {
+  pub fn new_child(
+    &mut self,
+    ns: Option<Namespace>,
+    name: &str,
+  ) -> Result<Node, Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     let ns_ptr = match ns {
       None => ptr::null_mut(),
@@ -775,7 +832,7 @@ impl Node {
     ns: Option<Namespace>,
     name: &str,
     content: &str,
-  ) -> Result<Node, Box<dyn Error>> {
+  ) -> Result<Node, Box<dyn Error + Send + Sync>> {
     let c_name = CString::new(name).unwrap();
     let c_content = CString::new(content).unwrap();
     let ns_ptr = match ns {
@@ -794,7 +851,7 @@ impl Node {
   }
 
   /// Append text to this `Node`
-  pub fn append_text(&mut self, content: &str) -> Result<(), Box<dyn Error>> {
+  pub fn append_text(&mut self, content: &str) -> Result<(), Box<dyn Error + Send + Sync>> {
     let c_len = content.len() as i32;
     if c_len > 0 {
       let c_content = CString::new(content).unwrap();
@@ -868,7 +925,7 @@ impl Node {
 
   /// find nodes via xpath, at a specified node or the document root
   pub fn findnodes(&self, xpath: &str) -> Result<Vec<Node>, ()> {
-    let mut context = Context::from_node(&self)?;
+    let mut context = Context::from_node(self)?;
     context.findnodes(xpath, Some(self))
   }
 
@@ -878,7 +935,7 @@ impl Node {
     &mut self,
     mut new: Node,
     mut old: Node,
-  ) -> Result<Node, Box<dyn Error>> {
+  ) -> Result<Node, Box<dyn Error + Send + Sync>> {
     // if newNode == oldNode or self == newNode then do nothing, just return nNode.
     if new == old || self == &new {
       // nothing to do here, already in place
